pub struct OcrBlock {
pub page: u32,
pub text: String,
pub confidence: Option<f32>,
pub detection_confidence: Option<f32>,
pub polygon: Option<[OcrPoint; 4]>,
pub bounding_box: Option<OcrBoundingBox>,
}Fields
page: u32text: Stringconfidence: Option<f32>detection_confidence: Option<f32>polygon: Option<[OcrPoint; 4]>bounding_box: Option<OcrBoundingBox>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for OcrBlock
impl<'de> Deserialize<'de> for OcrBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OcrBlock
impl JsonSchema for OcrBlock
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for OcrBlock