pub struct OcrBoundingBox {
pub x: u32,
pub y: u32,
pub width: u32,
pub height: u32,
}Fields
x: u32y: u32width: u32height: u32Trait Implementations
Sourceimpl Clone for OcrBoundingBox
impl Clone for OcrBoundingBox
Sourcefn clone(&self) -> OcrBoundingBox
fn clone(&self) -> OcrBoundingBox
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OcrBoundingBox
Sourceimpl Debug for OcrBoundingBox
impl Debug for OcrBoundingBox
Sourceimpl<'de> Deserialize<'de> for OcrBoundingBox
impl<'de> Deserialize<'de> for OcrBoundingBox
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OcrBoundingBox
Sourceimpl JsonSchema for OcrBoundingBox
impl JsonSchema for OcrBoundingBox
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OcrBoundingBox
impl PartialEq for OcrBoundingBox
Sourceimpl Serialize for OcrBoundingBox
impl Serialize for OcrBoundingBox
impl StructuralPartialEq for OcrBoundingBox