pub struct OcrRequest {
pub path: PathBuf,
}Fields
path: PathBufTrait Implementations
Sourceimpl Clone for OcrRequest
impl Clone for OcrRequest
Sourcefn clone(&self) -> OcrRequest
fn clone(&self) -> OcrRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OcrRequest
impl Debug for OcrRequest
Sourceimpl<'de> Deserialize<'de> for OcrRequest
impl<'de> Deserialize<'de> for OcrRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OcrRequest
Sourceimpl JsonSchema for OcrRequest
impl JsonSchema for OcrRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OcrRequest
impl PartialEq for OcrRequest
Sourceimpl Serialize for OcrRequest
impl Serialize for OcrRequest
impl StructuralPartialEq for OcrRequest